# free

Free yourself from captcha traps!


## Description

Uses pytesseract and custom neural nets to mimic human behavior at captcha prompts.

## Installation

```bash
pip install free
```

## Contribute

```bash
git clone https://github.com/totalgood/free.git
```
